==> 2.5.2.tar.gz: lib/indicator.dart <==
library indicator;

import 'dart:core';
import 'api.dart';
import 'function.dart';
import 'variables.dart';
import 'dart:developer';
import 'package:geiger_api/geiger_api.dart';
import 'data.dart';
import 'package:geiger_localstorage/geiger_localstorage.dart';

Future runIndicator(var indicatorID) async {
  final localMaster =
  (await getGeigerApi("", GeigerApi.masterId, Declaration.doNotShareData))
  !;
  Storage.controller = localMaster.getStorage();
  Storage.geigerIndicatorUUID = indicatorID;
  log("=======================indicator ID"+ Storage.geigerIndicatorUUID);

  await getUUID();

//  await createEterprise();
//  await createEnterpriseUsers();
//  await createEnterpriseDevices();
  await createPlugin(); //temporary

  await initPlugin(); //check exist of mertic data
  await setValueListener(); //Init Listener
  await checkExistNodes();

  await getRisk(); //global data
  await getRecommendation(); //global data

  log(Storage.getValuePath.length.toString());

  log("++getMetrics");
  await getMetrics(Types.users, Storage.userUUID);
  log("++updateScoreNode");
  await updateScoreNode(Types.users, Types.geigerScoreUser);
  log("++updateRecommendationNode");
  await updateRecommendationNode(Types.users);

  await getMetrics(Types.devices, Storage.deviceUUID);
  await updateScoreNode(Types.devices, Types.geigerScoreDevice);
  await updateRecommendationNode(Types.devices);

  await getDevices();
  await getEmployees();
  await crtAggregateScore();
  await updateScoreNode(Types.users, Types.geigerScoreAggregate);

  updateScoreMSENode();
  //GeigerScoreUser GeigerScoreDevice
  //:Users:85f99951-eed4-4bca-8cab-2b72326579d2:1234-1234-1234:data:GeigerScoreAggregate
  log('indiA Done ${Storage.controller!.dump(':Users:${Storage.userUUID}:${Storage.geigerIndicatorUUID}:data:GeigerScoreAggregate')}');
  log('indiA Done ${Storage.controller!.dump(':Users:${Storage.userUUID}:${Storage.geigerIndicatorUUID}:data:GeigerScoreUser')}');
  log('indiA Done ${Storage.controller!.dump(':Devices:${Storage.deviceUUID}:${Storage.geigerIndicatorUUID}:data:GeigerScoreDevice')}');



}




Future createPlugin() async{

  //:Local:plugin
  Node plugins = NodeImpl(':Local:plugin','');
//  try {
//    await Storage.controller!.addOrUpdate(plugins);
//  } catch (e, s) {
//    print(e);
//  }

  // final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/local.csv').openRead();
  // final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();

  for ( var object in data.local){

    try {

      Node temp = NodeImpl(object['UUID']!,'',':Local:plugin');
      await temp.addValue(NodeValueImpl('appname', object['Name']!));
      await temp.addValue(NodeValueImpl('company', object['company']!));
      await plugins.addChild(temp);

    }
    catch(e){
      log(e.toString());
    }
  }

  await Storage.controller!.addOrUpdate(plugins);
  //print(await Storage.controller!.get(':Local:plugin'));
}



Future createEnterprise() async{

  //:Enterprise
//  Node enterprise = NodeImpl(':Enterprise');
//  Storage.controller!.addOrUpdate(enterprise);

//  final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/Enterprise.csv').openRead();
//  final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();

//  for ( var str in fields[0].toString().replaceAll('[', '').split('\n') ){

  try {

    Node temp = NodeImpl(':Enterprise','');
    await temp.addValue(NodeValueImpl('name', data.enter['Name'].toString()));
    await temp.addValue(NodeValueImpl('location', data.enter['location'].toString()));
    await temp.addValue(NodeValueImpl('sector', data.enter['sector'].toString()));
    await temp.addValue(NodeValueImpl('associatedProfiles', data.enter['associatedProfiles'].toString()));

    await Storage.controller!.addOrUpdate(temp);
  }
  catch(e){

  print(e);

  }
  // }

//  var get = await Storage.controller!.get(':Enterprise');
//  print(await get.getChildren());

}


Future createEnterpriseDevices() async{

  //:Enterprise
//  Node enterprise = NodeImpl(':Enterprise');
//  Storage.controller!.addOrUpdate(enterprise);

//  final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/enterpriseDevices.csv').openRead();
//  final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();


  for ( var str in data.enterDevice ){

    try {

      Node temp = NodeImpl(str['UUID'].toString(),'', ':Devices');
      await temp.addValue(NodeValueImpl('name', str['name'].toString()));
      await temp.addValue(NodeValueImpl('type', str['type'].toString()));
      await temp.addValue(NodeValueImpl('owner', str['owner'].toString()));
      await Storage.controller!.addOrUpdate(temp);
  }

  catch(e){

  print(e);
  }
  }

  Node temp = await Storage.controller!.get(':Devices:'+Storage.deviceUUID);
  await temp.addValue(NodeValueImpl('name', 'geiger'));
  await temp.addValue(NodeValueImpl('type', 'mobile'));
  await temp.addValue(NodeValueImpl('owner', Storage.userUUID));
  await Storage.controller!.addOrUpdate(temp);


  var get = await Storage.controller!.get(':Devices');
//  print(await get.getChildren());

  //print(Storage.controller!.get(':Devices').getChildren());

  }


Future createEnterpriseUsers() async {

  //":Global:profiles"
  Node enterpriseUsers = NodeImpl(':Enterprise:users','');
  try {
    await Storage.controller!.addOrUpdate(enterpriseUsers);
  } catch (e) {
    log('indiA-createEnterpriseUsers ${e.toString()}');

  }

  // Map x = json.decode(await File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/enterpriseUsers.json').readAsString());


  var t =  data.enterUsers.entries.iterator;

  while(t.moveNext()){

  var nodeArrays = t.current.value;

  for(var node in nodeArrays){

  Node temp = NodeImpl(node['UUID'].toString(),'', ':Enterprise:users');
  await temp.addValue(NodeValueImpl('name',node['name'].toString()));
  await temp.addValue(NodeValueImpl('firstName',node['firstName'].toString()));
  await temp.addValue(NodeValueImpl('UUIDs',node['UUIDs'].toString()));
  await temp.addValue(NodeValueImpl('mainUser',node['mainUser'].toString()));
  await temp.addValue(NodeValueImpl('supervising',node['supervising'].toString()));

  await enterpriseUsers.addChild(temp);

  }


  }

  Node temp = NodeImpl(Storage.userUUID,'', ':Enterprise:users');
  await temp.addValue(NodeValueImpl('name','geiger'));
  await temp.addValue(NodeValueImpl('firstName','g'));
  await temp.addValue(NodeValueImpl('UUIDs',Storage.userUUID));
  await temp.addValue(NodeValueImpl('mainUser','1'));
  await temp.addValue(NodeValueImpl('supervising','328161f6-89bd-49f6-user-5a375ff56ben, 328161f6-89bd-49f6-user-5a375ff58cal, 328161f6-89bd-49f6-user-5a375ff58deb'));

  await enterpriseUsers.addChild(temp);

  try {
  await Storage.controller!.addOrUpdate(enterpriseUsers);
  } catch (e, s) {
  print(s);
  }
//
//  var get = await Storage.controller!.get(':Devices');
//  print(await get.getChildren());



}

==> 2.5.3.tar.gz: lib/indicator.dart <==
library indicator;

import 'dart:core';
import 'api.dart';
import 'function.dart';
import 'variables.dart';
import 'dart:developer';
import 'package:geiger_api/geiger_api.dart';
import 'data.dart';
import 'package:geiger_localstorage/geiger_localstorage.dart';

Future runIndicator(var indicatorID) async {
  final localMaster =
  (await getGeigerApi("", GeigerApi.masterId, Declaration.doNotShareData))
  !;
  Storage.controller = localMaster.getStorage();
  Storage.geigerIndicatorUUID = indicatorID;
  log("=======================indicator ID"+ Storage.geigerIndicatorUUID);

  await getUUID();

//  await createEterprise();
//  await createEnterpriseUsers();
//  await createEnterpriseDevices();
  await createPlugin(); //temporary

  await initPlugin(); //check exist of mertic data
  await setValueListener(); //Init Listener
  await checkExistNodes();

  await getRisk(); //global data
  await getRecommendation(); //global data

  log(Storage.getValuePath.length.toString());

  log("++getMetrics");
  await getMetrics(Types.users, Storage.userUUID);
  log("++updateScoreNode");
  await updateScoreNode(Types.users, Types.geigerScoreUser);
  log("++updateRecommendationNode");
  await updateRecommendationNode(Types.users);

  await getMetrics(Types.devices, Storage.deviceUUID);
  await updateScoreNode(Types.devices, Types.geigerScoreDevice);
  await updateRecommendationNode(Types.devices);

  await getDevices();
  await getEmployees();
  await crtAggregateScore();
  await updateScoreNode(Types.users, Types.geigerScoreAggregate);

  updateScoreMSENode();
  //GeigerScoreUser GeigerScoreDevice
  //:Users:85f99951-eed4-4bca-8cab-2b72326579d2:1234-1234-1234:data:GeigerScoreAggregate
  log('indiA GeigerScoreAggregate ${await Storage.controller!.dump(':Users:${Storage.userUUID}:${Storage.geigerIndicatorUUID}:data:GeigerScoreAggregate')}');
  log('indiA GeigerScoreUser ${await Storage.controller!.dump(':Users:${Storage.userUUID}:${Storage.geigerIndicatorUUID}:data:GeigerScoreUser')}');
  log('indiA GeigerScoreDevice ${await Storage.controller!.dump(':Devices:${Storage.deviceUUID}:${Storage.geigerIndicatorUUID}:data:GeigerScoreDevice')}');



}




Future createPlugin() async{

  //:Local:plugin
  Node plugins = NodeImpl(':Local:plugin','');
//  try {
//    await Storage.controller!.addOrUpdate(plugins);
//  } catch (e, s) {
//    print(e);
//  }

  // final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/local.csv').openRead();
  // final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();

  for ( var object in data.local){

    try {

      Node temp = NodeImpl(object['UUID']!,'',':Local:plugin');
      await temp.addValue(NodeValueImpl('appname', object['Name']!));
      await temp.addValue(NodeValueImpl('company', object['company']!));
      await plugins.addChild(temp);

    }
    catch(e){
      log(e.toString());
    }
  }

  await Storage.controller!.addOrUpdate(plugins);
  //print(await Storage.controller!.get(':Local:plugin'));
}



Future createEnterprise() async{

  //:Enterprise
//  Node enterprise = NodeImpl(':Enterprise');
//  Storage.controller!.addOrUpdate(enterprise);

//  final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/Enterprise.csv').openRead();
//  final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();

//  for ( var str in fields[0].toString().replaceAll('[', '').split('\n') ){

  try {

    Node temp = NodeImpl(':Enterprise','');
    await temp.addValue(NodeValueImpl('name', data.enter['Name'].toString()));
    await temp.addValue(NodeValueImpl('location', data.enter['location'].toString()));
    await temp.addValue(NodeValueImpl('sector', data.enter['sector'].toString()));
    await temp.addValue(NodeValueImpl('associatedProfiles', data.enter['associatedProfiles'].toString()));

    await Storage.controller!.addOrUpdate(temp);
  }
  catch(e){

  print(e);

  }
  // }

//  var get = await Storage.controller!.get(':Enterprise');
//  print(await get.getChildren());

}


Future createEnterpriseDevices() async{

  //:Enterprise
//  Node enterprise = NodeImpl(':Enterprise');
//  Storage.controller!.addOrUpdate(enterprise);

//  final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/enterpriseDevices.csv').openRead();
//  final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();


  for ( var str in data.enterDevice ){

    try {

      Node temp = NodeImpl(str['UUID'].toString(),'', ':Devices');
      await temp.addValue(NodeValueImpl('name', str['name'].toString()));
      await temp.addValue(NodeValueImpl('type', str['type'].toString()));
      await temp.addValue(NodeValueImpl('owner', str['owner'].toString()));
      await Storage.controller!.addOrUpdate(temp);
  }

  catch(e){

  print(e);
  }
  }

  Node temp = await Storage.controller!.get(':Devices:'+Storage.deviceUUID);
  await temp.addValue(NodeValueImpl('name', 'geiger'));
  await temp.addValue(NodeValueImpl('type', 'mobile'));
  await temp.addValue(NodeValueImpl('owner', Storage.userUUID));
  await Storage.controller!.addOrUpdate(temp);


  var get = await Storage.controller!.get(':Devices');
//  print(await get.getChildren());

  //print(Storage.controller!.get(':Devices').getChildren());

  }


Future createEnterpriseUsers() async {

  //":Global:profiles"
  Node enterpriseUsers = NodeImpl(':Enterprise:users','');
  try {
    await Storage.controller!.addOrUpdate(enterpriseUsers);
  } catch (e) {
    log('indiA-createEnterpriseUsers ${e.toString()}');

  }

  // Map x = json.decode(await File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/enterpriseUsers.json').readAsString());


  var t =  data.enterUsers.entries.iterator;

  while(t.moveNext()){

  var nodeArrays = t.current.value;

  for(var node in nodeArrays){

  Node temp = NodeImpl(node['UUID'].toString(),'', ':Enterprise:users');
  await temp.addValue(NodeValueImpl('name',node['name'].toString()));
  await temp.addValue(NodeValueImpl('firstName',node['firstName'].toString()));
  await temp.addValue(NodeValueImpl('UUIDs',node['UUIDs'].toString()));
  await temp.addValue(NodeValueImpl('mainUser',node['mainUser'].toString()));
  await temp.addValue(NodeValueImpl('supervising',node['supervising'].toString()));

  await enterpriseUsers.addChild(temp);

  }


  }

  Node temp = NodeImpl(Storage.userUUID,'', ':Enterprise:users');
  await temp.addValue(NodeValueImpl('name','geiger'));
  await temp.addValue(NodeValueImpl('firstName','g'));
  await temp.addValue(NodeValueImpl('UUIDs',Storage.userUUID));
  await temp.addValue(NodeValueImpl('mainUser','1'));
  await temp.addValue(NodeValueImpl('supervising','328161f6-89bd-49f6-user-5a375ff56ben, 328161f6-89bd-49f6-user-5a375ff58cal, 328161f6-89bd-49f6-user-5a375ff58deb'));

  await enterpriseUsers.addChild(temp);

  try {
  await Storage.controller!.addOrUpdate(enterpriseUsers);
  } catch (e, s) {
  print(s);
  }
//
//  var get = await Storage.controller!.get(':Devices');
//  print(await get.getChildren());



}
